Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1229)

Unified Diff: content/browser/frame_host/frame_tree_node.h

Issue 2655663004: Introduce content-side Feature Policy object and maintain in parallel with renderer policy. (Closed)
Patch Set: Add comments for public enum members Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | content/browser/frame_host/frame_tree_node.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/frame_host/frame_tree_node.h
diff --git a/content/browser/frame_host/frame_tree_node.h b/content/browser/frame_host/frame_tree_node.h
index 503911bb69c27ca294316b4500801b1c45357c55..7a4a0b9e20425f5b7d359840ccbc2d57f2dffbfc 100644
--- a/content/browser/frame_host/frame_tree_node.h
+++ b/content/browser/frame_host/frame_tree_node.h
@@ -161,12 +161,11 @@ class CONTENT_EXPORT FrameTreeNode {
// Set the current name and notify proxies about the update.
void SetFrameName(const std::string& name, const std::string& unique_name);
- // Set the frame's feature policy from an HTTP header, clearing any existing
- // policy.
+ // Set the frame's feature policy header, clearing any existing header.
void SetFeaturePolicyHeader(const ParsedFeaturePolicyHeader& parsed_header);
- // Clear any feature policy associated with the frame.
- void ResetFeaturePolicy();
+ // Clear any feature policy header associated with the frame.
+ void ResetFeaturePolicyHeader();
// Add CSP header to replication state and notify proxies about the update.
void AddContentSecurityPolicy(const ContentSecurityPolicyHeader& header);
« no previous file with comments | « no previous file | content/browser/frame_host/frame_tree_node.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698